==> nextcloud-31.0.10.tgz: nextcloud/apps/circles/l10n/ro.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Ai șters {circle}",
    "{author} deleted {circle}" : "{author} a șters {circle}",
    "You removed {member} from {circle}" : "Ai îndepărtat pe {member} din {circle}",
    "You joined {circle}" : "Te-ai alăturat cercului {circle}",
    "{member} joined {circle}" : "{member} s-a alăturat cercului {circle}",
    "You accepted the invitation to join {circle}" : "Ai acceptat invitația să te alături cercului {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} a acceptat invitația să se alăture cercului {circle}",
    "You added {member} as member to {circle}" : "Ai adăugat pe {member} ca membru în {circle}",
    "You have been added as member to {circle} by {author}" : "Ai fost adăugat ca membru în {circle} de {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} a fost adăugat ca membru în {circle} de {author}",
    "You added {external} to {circle}" : "Ai adăugat {external} în {circle}",
    "{external} has been added to {circle} by {author}" : "{external} a fost adăugat în {circle} de {author}",
    "You accepted {member}'s request to join {circle}" : "Ai acceptat cererea lui {member} de alăturare în {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Cererea ta de alăturare în {circle} a fost acceptată de {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Cererea lui {member} de alăturare în {circle} a fost acceptată de {author}",
    "You left {circle}" : "Ai părăsit {circle}",
    "{member} left {circle}" : "{member} a părăsit {circle}",
    "You declined the invitation to join {circle}" : "Ai declinat invitația de alăturare în {circle}",
    "{member} declined an invitation to join {circle}" : "{member} a declinat invitația de alăturare în {circle}",
    "You cancelled your request to join {circle}" : "Ai anulat cererea de a te alătura {circle}",
    "You have been removed from {circle} by {author}" : "Ai fost îndepărtat din {circle} de {author}",
    "{member} has been removed from {circle} by {author}" : "{member} a fost îndepărtat din {circle} de {author}",
    "You removed {external} from {circle}" : "Ai îndepărtat {external} din {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} a fost îndepărtat din {circle} de {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Ai anulat invitația lui {member} de a se alătura {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Invitația ta de a te alătura {circle} a fost anulată de {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} a anulat invitația lui {member} de a se alătura {circle}",
    "You dismissed {member}'s request to join {circle}" : "Ai ignorat cererea lui {member} de a se alătura {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Cererea ta de a te alătura {circle} a fost ignorată de {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Cererea lui {member} de a se alătura {circle} a fost ignorată de {author}",
    "You invited {member} to join {circle}" : "Ai invitat pe {member} să se alăture {circle}",
    "You have been invited to join {circle} by {author}" : "Ai fost invitat să te alături {circle} de {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} a fost invitat să se alăture {circle} de {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Ai schimbat nivelul lui {member} în {circle} la %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} a schimbat nivelul tău în {circle} la %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} a schimbat nivelul lui {member} în {circle} la %1$s",
    "You sent a request to join {circle}" : "Ai trimis o cerere să te alături {circle}",
    "{member} sent a request to join {circle}" : "{member} a trimis o cerere să se alăture {circle}",
    "You are the new owner of {circle}" : "Ești noul proprietar al {circle}",
    "{member} is the new owner of {circle}" : "{member} este noul proprietar al {circle}",
    "Single" : "Singur",
    "Personal" : "Personal",
    "System" : "Sistem",
    "Visible" : "Vizibil",
    "Open" : "Deschide",
    "Invite" : "Invită",
    "Friends" : "Prieteni",
    "Password protected" : "Protejat cu parolă",
    "No Owner" : "Niciun proprietar",
    "Hidden" : "Ascuns",
    "Local" : "Local",
    "Root" : "Root",
    "Federated" : "Federated",
    "Mount point" : "Punct de montare",
    "Nextcloud Account" : "Cont Nextcloud",
    "Nextcloud Group" : "Grup Nextcloud",
    "Email address" : "Email",
    "Contact" : "Contact",
    "Team" : "Echipă",
    "Nextcloud App" : "Aplicație Nextcloud",
    "Member" : "Membru",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Proprietar",
    "%s shared »%s« with you." : "%s a împărțit »%s« cu tine.",
    "%s shared »%s« with \"%s\"." : "%s a partejat »%s« cu \"%s\".",
    "%s on %s" : "%s pe %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partajat »%2$s« cu tine.\nTrebuie să fi primit deja un email separat cu linkul de acces.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s a partajat »%2$s« cu tine. Trebuie să fi primit deja un mail separat cu linkul de acces.",
    "Password to access »%1$s« shared to you by %2$s" : "Parola pentru a accesa »%1$s« partajată cu tine de către %2$s",
    "Password to access »%s«" : "Parola pentru access »%s«",
    "It is protected with the following password:" : "Este protejat cu urmatoarea parolă:",
    "%1$s via %2$s" : "%1$sprin %2$s",
    "Click the button below to open it." : "Apasă pe butonul de jos pentru a deschide.",
    "Open »%s«" : "Deschide »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s a partajat mai multe fișiere cu tine.\nTrebuie să fi primit deja un mail separat cu linkul de acces.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s a partajat mai multe fișiere cu tine. Trebuie să fi primit deja un mail separat cu linkul de acces.",
    "Password to access files shared to you by %1$s" : "Parola pentru fișierele partajate de %1$s",
    "Password to access files" : "Parola pentru accesarea fișierelor",
    "%s shared multiple files with \"%s\"." : "%s a partajat mai multe fișiere cu \"%s\".",
    "%s shared multiple files with you." : "%s a partajat mai multe fișiere cu tine.",
    "Nextcloud Initialization" : "Inițializare Nextcloud",
    "Circles App Initialization" : "Inițializare aplicație Cercuri",
    "Fresh installation status" : "Statusul noii instalări",
    "Building Local Database" : "Se creează baza de date locală",
    "Testing Basic Circle Creation" : "Se testează crearea Cercului de bază",
    "Adding local users and moderators" : "Se adaugă utilizatorii locali și moderatorii",
    "This feature is not available for personal circles" : "Această caracteristică nu este disponibilă pentru cercurile personale",
    "This member is not a moderator" : "Acest membru nu este un moderator",
    "Insufficient privileges" : "Privilegii insuficiente",
    "This member does not exist" : "Acest membru nu există",
    "Level cannot be changed for this type of member" : "Nivelul nu poate fi schimbat pentru acest tip de membru",
    "You are already a member of this circle" : "Ești deja membru în acest cerc",
    "You have been blocked from this circle" : "Ai fost blocat din acest cerc",
    "The account is already a member of this circle" : "Contul este deja membru al acestui cerc",
    "The account has already been invited into this circle" : "Contul a fost deja invitat la acest cerc",
    "Accept" : "Accept",
    "Refuse" : "Refuză",
    "%s" : "%s",
    "%s owned by %s" : "%s proprietatea lui %s",
    "%s shared a file with \"%s\"." : "%s a partajat un fișier cu \"%s\".",
    "%s shared a file with you." : "%s a partajat un fișier cu tine.",
    "Open %s" : "Deschide %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partajat ceva cu tine.\nTrebuie să fi primit deja un email separat cu linkul de acces.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s a partajat ceva cu tine. Trebuie să fi primit un email separat cu linkul de acces.",
    "Password to access content shared with you by %1$s" : "Parola pentru accesarea conținutului partajat de %1$s",
    "Password to access content" : "Parola pentru accesarea conținutului",
    "Bring cloud-users closer together." : "Adu utilizatorii cloud-ului mai aproape.",
    "Loading…" : "Se încarcă...",
    "No files in here" : "Nu sunt fișiere aici",
    "No entries found in this folder" : "Nici o intrare găsită în acest folder",
    "Name" : "Nume",
    "Size" : "Mărime",
    "Modified" : "Modificat",
    "Shared to Circles" : "Distribuit în Cercuri"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-31.0.11.tgz: nextcloud/apps/circles/l10n/ro.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Ai șters {circle}",
    "{author} deleted {circle}" : "{author} a șters {circle}",
    "You removed {member} from {circle}" : "Ai îndepărtat pe {member} din {circle}",
    "You joined {circle}" : "Te-ai alăturat cercului {circle}",
    "{member} joined {circle}" : "{member} s-a alăturat cercului {circle}",
    "You accepted the invitation to join {circle}" : "Ai acceptat invitația să te alături cercului {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} a acceptat invitația să se alăture cercului {circle}",
    "You added {member} as member to {circle}" : "Ai adăugat pe {member} ca membru în {circle}",
    "You have been added as member to {circle} by {author}" : "Ai fost adăugat ca membru în {circle} de {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} a fost adăugat ca membru în {circle} de {author}",
    "You added {external} to {circle}" : "Ai adăugat {external} în {circle}",
    "{external} has been added to {circle} by {author}" : "{external} a fost adăugat în {circle} de {author}",
    "You accepted {member}'s request to join {circle}" : "Ai acceptat cererea lui {member} de alăturare în {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Cererea ta de alăturare în {circle} a fost acceptată de {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Cererea lui {member} de alăturare în {circle} a fost acceptată de {author}",
    "You left {circle}" : "Ai părăsit {circle}",
    "{member} left {circle}" : "{member} a părăsit {circle}",
    "You declined the invitation to join {circle}" : "Ai declinat invitația de alăturare în {circle}",
    "{member} declined an invitation to join {circle}" : "{member} a declinat invitația de alăturare în {circle}",
    "You cancelled your request to join {circle}" : "Ai anulat cererea de a te alătura {circle}",
    "You have been removed from {circle} by {author}" : "Ai fost îndepărtat din {circle} de {author}",
    "{member} has been removed from {circle} by {author}" : "{member} a fost îndepărtat din {circle} de {author}",
    "You removed {external} from {circle}" : "Ai îndepărtat {external} din {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} a fost îndepărtat din {circle} de {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Ai anulat invitația lui {member} de a se alătura {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Invitația ta de a te alătura {circle} a fost anulată de {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} a anulat invitația lui {member} de a se alătura {circle}",
    "You dismissed {member}'s request to join {circle}" : "Ai ignorat cererea lui {member} de a se alătura {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Cererea ta de a te alătura {circle} a fost ignorată de {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Cererea lui {member} de a se alătura {circle} a fost ignorată de {author}",
    "You invited {member} to join {circle}" : "Ai invitat pe {member} să se alăture {circle}",
    "You have been invited to join {circle} by {author}" : "Ai fost invitat să te alături {circle} de {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} a fost invitat să se alăture {circle} de {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Ai schimbat nivelul lui {member} în {circle} la %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} a schimbat nivelul tău în {circle} la %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} a schimbat nivelul lui {member} în {circle} la %1$s",
    "You sent a request to join {circle}" : "Ai trimis o cerere să te alături {circle}",
    "{member} sent a request to join {circle}" : "{member} a trimis o cerere să se alăture {circle}",
    "You are the new owner of {circle}" : "Ești noul proprietar al {circle}",
    "{member} is the new owner of {circle}" : "{member} este noul proprietar al {circle}",
    "Single" : "Singur",
    "Personal" : "Personal",
    "System" : "Sistem",
    "Visible" : "Vizibil",
    "Open" : "Deschide",
    "Invite" : "Invită",
    "Friends" : "Prieteni",
    "Password protected" : "Protejat cu parolă",
    "No Owner" : "Niciun proprietar",
    "Hidden" : "Ascuns",
    "Local" : "Local",
    "Root" : "Root",
    "Federated" : "Federated",
    "Mount point" : "Punct de montare",
    "Nextcloud Account" : "Cont Nextcloud",
    "Nextcloud Group" : "Grup Nextcloud",
    "Email address" : "Email",
    "Contact" : "Contact",
    "Team" : "Echipă",
    "Nextcloud App" : "Aplicație Nextcloud",
    "Member" : "Membru",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Proprietar",
    "%s shared »%s« with you." : "%s a împărțit »%s« cu tine.",
    "%s shared »%s« with \"%s\"." : "%s a partejat »%s« cu \"%s\".",
    "%s on %s" : "%s pe %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partajat »%2$s« cu tine.\nTrebuie să fi primit deja un email separat cu linkul de acces.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s a partajat »%2$s« cu tine. Trebuie să fi primit deja un mail separat cu linkul de acces.",
    "Password to access »%1$s« shared to you by %2$s" : "Parola pentru a accesa »%1$s« partajată cu tine de către %2$s",
    "Password to access »%s«" : "Parola pentru access »%s«",
    "It is protected with the following password:" : "Este protejat cu urmatoarea parolă:",
    "%1$s via %2$s" : "%1$sprin %2$s",
    "Click the button below to open it." : "Apasă pe butonul de jos pentru a deschide.",
    "Open »%s«" : "Deschide »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s a partajat mai multe fișiere cu tine.\nTrebuie să fi primit deja un mail separat cu linkul de acces.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s a partajat mai multe fișiere cu tine. Trebuie să fi primit deja un mail separat cu linkul de acces.",
    "Password to access files shared to you by %1$s" : "Parola pentru fișierele partajate de %1$s",
    "Password to access files" : "Parola pentru accesarea fișierelor",
    "%s shared multiple files with \"%s\"." : "%s a partajat mai multe fișiere cu \"%s\".",
    "%s shared multiple files with you." : "%s a partajat mai multe fișiere cu tine.",
    "Nextcloud Initialization" : "Inițializare Nextcloud",
    "Circles App Initialization" : "Inițializare aplicație Cercuri",
    "Fresh installation status" : "Statusul noii instalări",
    "Building Local Database" : "Se creează baza de date locală",
    "Adding local users and moderators" : "Se adaugă utilizatorii locali și moderatorii",
    "This member is not a moderator" : "Acest membru nu este un moderator",
    "Insufficient privileges" : "Privilegii insuficiente",
    "This member does not exist" : "Acest membru nu există",
    "Level cannot be changed for this type of member" : "Nivelul nu poate fi schimbat pentru acest tip de membru",
    "Accept" : "Accept",
    "Refuse" : "Refuză",
    "%s" : "%s",
    "%s owned by %s" : "%s proprietatea lui %s",
    "%s shared a file with \"%s\"." : "%s a partajat un fișier cu \"%s\".",
    "%s shared a file with you." : "%s a partajat un fișier cu tine.",
    "Open %s" : "Deschide %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s a partajat ceva cu tine.\nTrebuie să fi primit deja un email separat cu linkul de acces.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s a partajat ceva cu tine. Trebuie să fi primit un email separat cu linkul de acces.",
    "Password to access content shared with you by %1$s" : "Parola pentru accesarea conținutului partajat de %1$s",
    "Password to access content" : "Parola pentru accesarea conținutului",
    "Bring cloud-users closer together." : "Adu utilizatorii cloud-ului mai aproape.",
    "Loading…" : "Se încarcă...",
    "No files in here" : "Nu sunt fișiere aici",
    "No entries found in this folder" : "Nici o intrare găsită în acest folder",
    "Name" : "Nume",
    "Size" : "Mărime",
    "Modified" : "Modificat",
    "Shared to Circles" : "Distribuit în Cercuri",
    "Testing Basic Circle Creation" : "Se testează crearea Cercului de bază",
    "This feature is not available for personal circles" : "Această caracteristică nu este disponibilă pentru cercurile personale",
    "You are already a member of this circle" : "Ești deja membru în acest cerc",
    "You have been blocked from this circle" : "Ai fost blocat din acest cerc",
    "The account is already a member of this circle" : "Contul este deja membru al acestui cerc",
    "The account has already been invited into this circle" : "Contul a fost deja invitat la acest cerc"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
